@@ -28,7 +28,7 @@
 #   http://www.open-xchange.com/EN/developer/. The contributing author shall be
 #   given Attribution for the derivative code and a license granting use.
 #
-#    Copyright (C) 2004-2010 Open-Xchange, Inc.
+#    Copyright (C) 2004-2012 Open-Xchange, Inc.
 #    Mail: info@open-xchange.com
 #
 #
@@ -127,6 +127,8 @@ ox_is_running() {
 
     if [ -e /var/run/${name}.pid ]; then
 	read PID < /var/run/${name}.pid
+	# take care nothing influences line length if ps output
+	COLUMNS=1000
 	if ps $PID | grep "$pattern" > /dev/null; then
 	   return 0
 	else
@@ -292,7 +294,7 @@ if ( $end > 0 ) {
     else
         # quote & in URLs to make sed happy
 	test -n "$val" && val="$(echo $val | sed 's/\&/\\\&/g')"
-	if grep -E "^$prop" $propfile >/dev/null; then
+	if grep -E "^$prop *[:=]" $propfile >/dev/null; then
 	    cat<<EOF | sed -f - $propfile > $tmp
 s;\(^$prop[[:space:]]*[:=]\).*$;\1${val};
 EOF
@@ -337,6 +339,9 @@ while(<FILE>) {
     chomp;
     my $len=length($search);
     if( substr($_,0,$len) eq $search ) {
+	if( substr($_,$len,$len+1) !~ /^[\s=:]/ ) {
+	   next;
+	}
         foreach my $dl ( "=", ":" ) {
            my $idx=index($_,$dl);
            if( $idx >= $len ) {
@@ -580,10 +585,18 @@ ox_remove_hosts_hostname() {
 }
 
 ox_save_backup() {
-	local name=$1
-	local backup_name="${name}.old"
-	if [ -e $name ]
-		then
-		mv $name $backup_name
-	fi
+    local name
+    for((i=9;i>=0;i--)); do
+        if [ $i == 0 ]; then
+                name=$1
+        else
+                name="${1}.${i}"
+        fi
+
+        local backup_name="${1}.$(($i + 1))"
+
+        if [ -e $name ]; then
+                mv $name $backup_name
+        fi 
+    done
 }
