@@ -28,10 +28,12 @@ import java.io.IOException;
 import java.io.Writer;
 import java.lang.reflect.Field;
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicInteger;
+import java.util.regex.Pattern;
+import org.json.hash.HashKeyMap;
 
 /**
  * A JSONObject is an unordered collection of name/value pairs. Its external
@@ -92,6 +94,17 @@ import java.util.Set;
  */
 public class JSONObject implements JSONValue {
 
+    private static final AtomicInteger MAX_SIZE = new AtomicInteger(0);
+
+    /**
+     * Sets the max. allowed size of a JSON object.
+     * 
+     * @param maxSize The max. allowed size or a value less than/equal to zero if unlimited
+     */
+    public static void setMaxSize(final int maxSize) {
+        MAX_SIZE.set(maxSize <= 0 ? 0 : maxSize);
+    }
+
 	private static final String STR_TRUE = "true";
 
 	private static final String STR_FALSE = "false";
@@ -161,7 +174,7 @@ public class JSONObject implements JSONValue {
 	 * Construct an empty JSONObject.
 	 */
 	public JSONObject() {
-		this.myHashMap = new HashMap<String, Object>();
+		this.myHashMap = new HashKeyMap<Object>();
 	}
 
 	/**
@@ -259,7 +272,14 @@ public class JSONObject implements JSONValue {
 	 *            the JSONObject.
 	 */
 	public JSONObject(final Map<String, ? extends Object> map) {
-		this.myHashMap = (map == null) ? new HashMap<String, Object>() : new HashMap<String, Object>(map);
+		this.myHashMap = new HashKeyMap<Object>();
+		if (null != map) {
+		    final int max = MAX_SIZE.get();
+            if (max > 0 && map.size() > max) {
+                throw new IllegalStateException("Max. size ("+max+") for JSON object exceeded");
+            }
+		    myHashMap.putAll(map);
+        }
 	}
 
 	/**
@@ -303,7 +323,7 @@ public class JSONObject implements JSONValue {
 	 *                If there is a syntax error in the source string.
 	 */
 	public JSONObject(final String string) throws JSONException {
-		this(new JSONTokener(string));
+		this(new JSONTokener(prepareJSONString(string)));
 	}
 	
 	/**
@@ -981,6 +1001,10 @@ public class JSONObject implements JSONValue {
 		}
 		if (value != null) {
 			testValidity(value);
+			final int max = MAX_SIZE.get();
+            if (max > 0 && this.myHashMap.size() >= max) {
+                throw new IllegalStateException("Max. size ("+max+") for JSON object exceeded");
+            }
 			this.myHashMap.put(key, value);
 		} else {
 			remove(key);
@@ -1384,4 +1408,14 @@ public class JSONObject implements JSONValue {
     public boolean isObject() {
         return true;
     }
+
+    private static final Pattern PATTERN_CRLF = Pattern.compile("\r?\n");
+
+    private static String prepareJSONString(final String sJson) {
+        if (null == sJson) {
+            return null;
+        }
+        return PATTERN_CRLF.matcher(sJson).replaceAll("");
+    }
+
 }
