@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -72,6 +72,16 @@ public final class Autoboxing {
         return b.byteValue();
     }
 
+    /**
+     * Short method name for {@link Integer#valueOf(String)} .
+     * @param str String value to be converted to an Integer object.
+     * @return Integer object.
+     */
+    public static Integer I(final String str) {
+        return Integer.valueOf(str);
+    }
+
+    
     /**
      * Short method name for {@link Integer#valueOf(int)} that uses cached instances for small values of integer.
      * @param i integer value to be converted to an Integer object.
@@ -99,7 +109,7 @@ public final class Autoboxing {
         return Long.valueOf(l);
     }
 
-    public static long l(Long l) {
+    public static long l(final Long l) {
         return l.longValue();
     }
 
@@ -117,7 +127,7 @@ public final class Autoboxing {
      * @param b {@link Boolean} object to be converted to a boolean value.
      * @return boolean value.
      */
-    public static boolean b(Boolean b) {
+    public static boolean b(final Boolean b) {
         return b.booleanValue();
     }
 
@@ -130,7 +140,7 @@ public final class Autoboxing {
         return Float.valueOf(f);
     }
 
-    public static float f(Float f) {
+    public static float f(final Float f) {
         return f.floatValue();
     }
 
@@ -139,8 +149,8 @@ public final class Autoboxing {
      * @param intArray int[] to be converted to Integer[]
      * @return Integer[]
      */
-    public static Integer[] i2I(int[] intArray) {
-        Integer[] integerArray = new Integer[intArray.length];
+    public static Integer[] i2I(final int[] intArray) {
+        final Integer[] integerArray = new Integer[intArray.length];
         for (int i = 0; i < intArray.length; i++) {
             integerArray[i] = I(intArray[i]);
         }
@@ -152,10 +162,18 @@ public final class Autoboxing {
      * @param integerArray Integer[] to be converted to int[]
      * @return int[]
      */
-    public static int[] I2i(Integer[] integerArray) {
+    public static int[] I2i(final Integer[] integerArray) {
         int[] intArray = new int[integerArray.length];
-        for (int i = 0; i < intArray.length; i++) {
-            intArray[i] = integerArray[i].intValue();
+        int pos = 0;
+        for (Integer i : integerArray) {
+            if (null != i) {
+                intArray[pos++] = i.intValue();
+            }
+        }
+        if (pos != intArray.length) {
+            final int[] tmpArray = new int[pos];
+            System.arraycopy(intArray, 0, tmpArray, 0, pos);
+            intArray = tmpArray;
         }
         return intArray;
     }
@@ -165,48 +183,71 @@ public final class Autoboxing {
      * @param integerCollection List of Integers to be converted to int[]
      * @return int[]
      */
-    public static int[] I2i(Collection<Integer> integerCollection) {
+    public static int[] I2i(final Collection<Integer> integerCollection) {
         int[] intArray = new int[integerCollection.size()];
         int pos = 0;
-        for (Integer i : integerCollection) {
-            intArray[pos++] = i.intValue();
+        for (final Integer i : integerCollection) {
+            if (null != i) {
+                intArray[pos++] = i.intValue();
+            }
+        }
+        if (pos != intArray.length) {
+            final int[] tmpArray = new int[pos];
+            System.arraycopy(intArray, 0, tmpArray, 0, pos);
+            intArray = tmpArray;
         }
         return intArray;
     }
-    
+
+    public static byte[] B2b(final Collection<Byte> byteCollection) {
+        byte[] byteArray = new byte[byteCollection.size()];
+        int pos = 0;
+        for (final Byte b : byteCollection) {
+            if (null != b) {
+                byteArray[pos++] = b.byteValue();
+            }
+        }
+        if (pos != byteArray.length) {
+            final byte[] tmpArray = new byte[pos];
+            System.arraycopy(byteArray, 0, tmpArray, 0, pos);
+            byteArray = tmpArray;
+        }
+        return byteArray;
+    }
+
     /**
      * Converts a long-array into a Long-array.
      * @param longArray long[] to be converted to Long[]
      * @return Long[]
      */
-    public static Long[] l2L(long[] longArray) {
-        Long[] longerArray = new Long[longArray.length];
+    public static Long[] l2L(final long[] longArray) {
+        final Long[] longerArray = new Long[longArray.length];
         for (int i = 0; i < longArray.length; i++) {
             longerArray[i] = L(longArray[i]);
         }
         return longerArray;
     }
-    
+
     /**
      * Conversts an objec-array into a Boolean-array
      * @param source
      * @return
      */
-    public static Boolean[] O2B(Object[] source) {
-        Boolean[] target = new Boolean[source.length];
+    public static Boolean[] O2B(final Object[] source) {
+        final Boolean[] target = new Boolean[source.length];
         for (int i = 0; i < source.length; i++) {
             target[i] = (Boolean) source[i];
         }
         return target;
     }
-    
+
     /**
      * Conversta an Object-array into a Number-array
      * @param source
      * @return
      */
-    public static Number[] O2N(Object[] source) {
-        Number[] target = new Number[source.length];
+    public static Number[] O2N(final Object[] source) {
+        final Number[] target = new Number[source.length];
         for (int i = 0; i < source.length; i++) {
             target[i] = (Number) source[i];
         }
@@ -218,24 +259,73 @@ public final class Autoboxing {
      * @param source
      * @return
      */
-    public static String[] O2S(Object[] source) {
-        String[] target = new String[source.length];
+    public static String[] O2S(final Object[] source) {
+        final String[] target = new String[source.length];
         for (int i = 0; i < source.length; i++) {
             target[i] = (String) source[i];
         }
         return target;
     }
-    
+
     /**
-     * Converst an Object-array into a Long-array
+     * Converts an Object-array into a Long-array
      * @param source
      * @return
      */
-    public static Long[] O2L(Object[] source) {
-        Long[] target = new Long[source.length];
+    public static Long[] O2L(final Object[] source) {
+        final Long[] target = new Long[source.length];
         for (int i = 0; i < source.length; i++) {
             target[i] = (Long) source[i];
         }
         return target;
     }
+
+    /**
+     * Converts a collection of integers into an int-array
+     */
+    public static int[] Coll2i(Collection<Integer> collection){
+    	int[] results = new int[collection.size()];
+    	int position = 0;
+    	for(Integer value : collection)
+    		results[position++] = value.intValue();
+    	return results;
+    }
+
+    // Type Coercion
+
+    public static int a2i(Object anything) {
+        if(anything == null) {
+            throw new NullPointerException("Can't convert null into integer");
+        }
+        if(Integer.class.isInstance(anything)){
+            return (Integer) anything;
+        }
+        if(Byte.class.isInstance(anything)) {
+            return (Byte) anything;
+        }
+        if(Long.class.isInstance(anything)) {
+            return ((Long) anything).intValue();
+        }
+        if(String.class.isInstance(anything)) {
+            return Integer.parseInt((String) anything);
+        }
+
+        throw new ClassCastException("I don't know how to turn "+anything+" of class "+anything.getClass().getName()+" into an int.");
+    }
+
+    public static boolean a2b(Object anything) {
+        if(anything == null) {
+            throw new NullPointerException("Can't convert null into boolean");
+        }
+        if(Boolean.class.isInstance(anything)){
+            return (Boolean) anything;
+        }
+
+        if(String.class.isInstance(anything)) {
+            return Boolean.parseBoolean((String) anything);
+        }
+
+        throw new ClassCastException("I don't know how to turn "+anything+" of class "+anything.getClass().getName()+" into a boolean.");
+    }
+
 }
