@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,14 +56,14 @@ import java.util.List;
 
 /**
  * {@link Strings} - A library for performing operations that create Strings
- * 
+ *
  * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a>
  */
 public class Strings {
 
     /**
      * Joins a collection of objects by connecting the results of their #toString() method with a connector
-     * 
+     *
      * @param coll Collection to be connected
      * @param connector Connector place between two objects
      * @return connected strings or null if collection == null or empty string if collection is empty
@@ -99,4 +99,46 @@ public class Strings {
         return join(list, connector);
     }
 
+    public static String join(final byte[] arr, final String connector) {
+        final List<Byte> list = new LinkedList<Byte>();
+        for (final Byte i : arr) {
+            list.add(i);
+        }
+        return join(list, connector);
+    }
+
+    /**
+     * Removes byte order marks from UTF8 strings.
+     * @return new instance of trimmed string - or reference to old one if unchanged
+     */
+    public static String trimBOM(String str) {
+		final byte[][] byteOrderMarks = new byte[][]{
+				new byte[]{(byte)0x00, (byte)0x00, (byte)0xFE,(byte)0xFF},
+				new byte[]{(byte)0xFF, (byte)0xFE, (byte)0x00,(byte)0x0},
+				new byte[]{(byte)0xEF, (byte)0xBB, (byte)0xBF},
+				new byte[]{(byte)0xFE, (byte)0xFF},
+				new byte[]{(byte)0xFE, (byte)0xFF}
+			};
+
+		byte[] bytes = str.getBytes();
+		for(byte[] bom: byteOrderMarks){
+			if(bom.length > bytes.length)
+				continue;
+
+			String pattern = new String(bom);
+			if(! str.startsWith(pattern))
+				continue;
+
+			int bomLen = new String(bom).getBytes().length; //sadly the BOM got encoded meanwhile
+
+			int len = bytes.length-bomLen;
+			byte[] trimmed = new byte[len];
+			for(int i = 0; i < len; i++)
+				trimmed[i] = bytes[i+bomLen];
+			return new String(trimmed);
+		}
+
+		return str;
+	}
+
 }
